@@ -13,14 +13,10 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.moves.urllib.parse import quote as urlquote
-from future.utils import itervalues
-
 import os
 import re
 import stat
+from urllib.parse import quote as urlquote
 
 from twisted.internet import defer
 from twisted.internet import utils
@@ -32,6 +28,7 @@ from buildbot.util import bytes2unicode
 from buildbot.util import private_tempdir
 from buildbot.util.git import GitMixin
 from buildbot.util.git import getSshKnownHostsContents
+from buildbot.util.misc import writeLocalFile
 from buildbot.util.state import StateMixin
 
 
@@ -73,11 +70,11 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
                          'use sshHostKey')
             sshPrivateKey = None
 
-        base.PollingChangeSource.__init__(self, name=name,
-                                          pollInterval=pollInterval,
-                                          pollAtLaunch=pollAtLaunch,
-                                          sshPrivateKey=sshPrivateKey,
-                                          sshHostKey=sshHostKey)
+        super().__init__(name=name,
+                         pollInterval=pollInterval,
+                         pollAtLaunch=pollAtLaunch,
+                         sshPrivateKey=sshPrivateKey,
+                         sshHostKey=sshHostKey)
 
         if project is None:
             project = ''
@@ -139,7 +136,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         try:
             self.lastRev = yield self.getState('lastRev', {})
 
-            base.PollingChangeSource.activate(self)
+            super().activate()
         except Exception as e:
             log.err(e, 'while initializing GitPoller repository')
 
@@ -184,7 +181,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         return branch
 
     def _trackerBranch(self, branch):
-        return u"refs/buildbot/{}/{}".format(urlquote(self.repourl, ''),
+        return "refs/buildbot/{}/{}".format(urlquote(self.repourl, ''),
                                         self._removeHeads(branch))
 
     @defer.inlineCallbacks
@@ -197,16 +194,19 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
             log.msg(e.args[0])
             return
 
-        branches = self.branches
+        branches = self.branches if self.branches else []
+        remote_refs = yield self._getBranches()
         if branches is True or callable(branches):
-            branches = yield self._getBranches()
             if callable(self.branches):
-                branches = [b for b in branches if self.branches(b)]
+                branches = [b for b in remote_refs if self.branches(b)]
             else:
-                branches = [b for b in branches if self._headsFilter(b)]
+                branches = [b for b in remote_refs if self._headsFilter(b)]
+        elif branches and remote_refs:
+            remote_branches = [self._removeHeads(b) for b in remote_refs]
+            branches = sorted(list(set(branches) & set(remote_branches)))
 
         refspecs = [
-            u'+{}:{}'.format(self._removeHeads(branch), self._trackerBranch(branch))
+            '+{}:{}'.format(self._removeHeads(branch), self._trackerBranch(branch))
             for branch in branches
         ]
 
@@ -300,7 +300,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         if not self.lastRev:
             return
         rebuild = False
-        if newRev in itervalues(self.lastRev):
+        if newRev in self.lastRev.values():
             if self.buildPushesWithNoCommits:
                 existingRev = self.lastRev.get(branch)
                 if existingRev is None:
@@ -318,7 +318,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         # get the change list
         revListArgs = (['--format=%H', '{}'.format(newRev)] +
                        ['^' + rev
-                        for rev in sorted(itervalues(self.lastRev))] +
+                        for rev in sorted(self.lastRev.values())] +
                        ['--'])
         self.changeCount = 0
         results = yield self._dovccmd('log', revListArgs, path=self.workdir)
@@ -365,7 +365,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
                 branch=bytes2unicode(self._removeHeads(branch)),
                 project=self.project,
                 repository=bytes2unicode(self.repourl, encoding=self.encoding),
-                category=self.category, src=u'git')
+                category=self.category, src='git')
 
     def _isSshPrivateKeyNeededForCommand(self, command):
         commandsThatNeedKey = [
@@ -376,52 +376,43 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
             return True
         return False
 
-    def _writeLocalFile(self, path, contents, mode=None):  # pragma: no cover
-        with open(path, 'w') as file:
-            if mode is not None:
-                os.chmod(path, mode)
-            file.write(contents)
-
     def _downloadSshPrivateKey(self, keyPath):
         # We change the permissions of the key file to be user-readable only so
         # that ssh does not complain. This is not used for security because the
         # parent directory will have proper permissions.
-        self._writeLocalFile(keyPath, self.sshPrivateKey, mode=stat.S_IRUSR)
+        writeLocalFile(keyPath, self.sshPrivateKey, mode=stat.S_IRUSR)
 
     def _downloadSshKnownHosts(self, path):
-        self._writeLocalFile(path, getSshKnownHostsContents(self.sshHostKey))
+        writeLocalFile(path, getSshKnownHostsContents(self.sshHostKey))
 
-    def _getSshDataPath(self):
-        return os.path.join(self.workdir, '.buildbot-ssh')
+    def _getSshPrivateKeyPath(self, ssh_data_path):
+        return os.path.join(ssh_data_path, 'ssh-key')
 
-    def _getSshPrivateKeyPath(self):
-        return os.path.join(self._getSshDataPath(), 'ssh-key')
-
-    def _getSshKnownHostsPath(self):
-        return os.path.join(self._getSshDataPath(), 'ssh-known-hosts')
+    def _getSshKnownHostsPath(self, ssh_data_path):
+        return os.path.join(ssh_data_path, 'ssh-known-hosts')
 
     @defer.inlineCallbacks
     def _dovccmd(self, command, args, path=None):
         if self._isSshPrivateKeyNeededForCommand(command):
-            key_dir = self._getSshDataPath()
-            with private_tempdir.PrivateTemporaryDirectory(name=key_dir):
-                stdout = yield self._dovccmdImpl(command, args, path)
+            with private_tempdir.PrivateTemporaryDirectory(
+                    dir=self.workdir, prefix='.buildbot-ssh') as tmp_path:
+                stdout = yield self._dovccmdImpl(command, args, path, tmp_path)
         else:
-            stdout = yield self._dovccmdImpl(command, args, path)
-        defer.returnValue(stdout)
+            stdout = yield self._dovccmdImpl(command, args, path, None)
+        return stdout
 
     @defer.inlineCallbacks
-    def _dovccmdImpl(self, command, args, path):
+    def _dovccmdImpl(self, command, args, path, ssh_workdir):
         full_args = []
         full_env = os.environ.copy()
 
         if self._isSshPrivateKeyNeededForCommand(command):
-            key_path = self._getSshPrivateKeyPath()
+            key_path = self._getSshPrivateKeyPath(ssh_workdir)
             self._downloadSshPrivateKey(key_path)
 
             known_hosts_path = None
             if self.sshHostKey is not None:
-                known_hosts_path = self._getSshKnownHostsPath()
+                known_hosts_path = self._getSshKnownHostsPath(ssh_workdir)
                 self._downloadSshKnownHosts(known_hosts_path)
 
             self.adjustCommandParamsForSshPrivateKey(full_args, full_env,
@@ -441,4 +432,4 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
                                full_args, path, self.repourl, code, stderr))
             raise EnvironmentError('command {} in {} on repourl {} failed with exit code {}: {}'.format(
                                    full_args, path, self.repourl, code, stderr))
-        defer.returnValue(stdout.strip())
+        return stdout.strip()
