@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 from functools import reduce
 
@@ -41,15 +38,12 @@ from buildbot.process.results import computeResultAndTermination
 from buildbot.process.results import statusToString
 from buildbot.process.results import worst_status
 from buildbot.reporters.utils import getURLForBuild
-from buildbot.util import bytes2NativeString
 from buildbot.util import bytes2unicode
 from buildbot.util.eventual import eventually
-from buildbot.worker_transition import WorkerAPICompatMixin
-from buildbot.worker_transition import deprecatedWorkerClassMethod
 
 
 @implementer(interfaces.IBuildControl)
-class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
+class Build(properties.PropertiesMixin):
 
     """I represent a single build by a single worker. Specialized Builders can
     use subclasses of Build to hold status information unique to those build
@@ -107,6 +101,10 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         self.results = SUCCESS
         self.properties = properties.Properties()
 
+        # tracks execution during the build finish phase
+        self._locks_released = False
+        self._build_finished = False
+
     def setBuilder(self, builder):
         """
         Set the given builder as our builder.
@@ -195,7 +193,6 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
 
     def getWorkerName(self):
         return self.workerforbuilder.worker.workername
-    deprecatedWorkerClassMethod(locals(), getWorkerName)
 
     @staticmethod
     def setupPropertiesKnownBeforeBuildStarts(props, requests, builder,
@@ -223,8 +220,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         # get worker properties
         # navigate our way back to the L{buildbot.worker.Worker}
         # object that came from the config, and get its properties
-        worker_properties = workerforbuilder.worker.properties
-        props.updateFromProperties(worker_properties)
+        workerforbuilder.worker.setupProperties(props)
 
     def setupOwnProperties(self):
         # now set some properties of our own, corresponding to the
@@ -248,14 +244,13 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         # object that came from the config, and get its properties
         if workerforbuilder.worker.worker_basedir:
             builddir = path_module.join(
-                bytes2NativeString(workerforbuilder.worker.worker_basedir),
-                bytes2NativeString(self.builder.config.workerbuilddir))
+                bytes2unicode(workerforbuilder.worker.worker_basedir),
+                bytes2unicode(self.builder.config.workerbuilddir))
             self.setProperty("builddir", builddir, "Worker")
 
     def setupWorkerForBuilder(self, workerforbuilder):
         self.path_module = workerforbuilder.worker.path_module
         self.workername = workerforbuilder.worker.workername
-        self._registerOldWorkerAttr("workername")
         self.build_status.setWorkername(self.workername)
 
     @defer.inlineCallbacks
@@ -277,7 +272,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
 
             else:
                 self._builderid = yield self.builder.getBuilderId()
-        defer.returnValue(self._builderid)
+        return self._builderid
 
     @defer.inlineCallbacks
     def startBuild(self, build_status, workerforbuilder):
@@ -309,7 +304,8 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         self.setupOwnProperties()
 
         # then narrow WorkerLocks down to the right worker
-        self.locks = [(l.getLock(workerforbuilder.worker), a)
+        self.locks = [(l.getLockForWorker(workerforbuilder.worker.workername),
+                       a)
                       for l, a in self.locks]
         metrics.MetricCountEvent.log('active_builds', 1)
 
@@ -317,7 +313,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         # events
         yield self._flushProperties(None)
         self.build_status.buildStarted(self)
-        yield self.master.data.updates.setBuildStateString(self.buildid, u'starting')
+        yield self.master.data.updates.setBuildStateString(self.buildid, 'starting')
         yield self.master.data.updates.generateNewBuildEvent(self.buildid)
 
         try:
@@ -331,7 +327,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         yield self._flushProperties(None)
 
         yield self.master.data.updates.setBuildStateString(self.buildid,
-                                                           u'preparing worker')
+                                                           'preparing worker')
         try:
             ready_or_failure = yield workerforbuilder.prepare(self)
         except Exception:
@@ -358,7 +354,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         # situations where the worker is live but is pushing lots of data to
         # us in a build.
         yield self.master.data.updates.setBuildStateString(self.buildid,
-                                                           u'pinging worker')
+                                                           'pinging worker')
         log.msg("starting build %s.. pinging the worker %s"
                 % (self, workerforbuilder))
         try:
@@ -390,11 +386,11 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
             return
 
         yield self.master.data.updates.setBuildStateString(self.buildid,
-                                                           u'acquiring locks')
+                                                           'acquiring locks')
         yield self.acquireLocks()
 
         yield self.master.data.updates.setBuildStateString(self.buildid,
-                                                           u'building')
+                                                           'building')
 
         # start the sequence of steps
         self.startNextStep()
@@ -411,9 +407,10 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         yield self.master.data.updates.finishStep(step.stepid, EXCEPTION, False)
 
     @staticmethod
-    def canStartWithWorkerForBuilder(lockList, workerforbuilder):
+    def _canAcquireLocks(lockList, workerforbuilder):
         for lock, access in lockList:
-            worker_lock = lock.getLock(workerforbuilder.worker)
+            worker_lock = lock.getLockForWorker(
+                workerforbuilder.worker.workername)
             if not worker_lock.isAvailable(None, access):
                 return False
         return True
@@ -529,7 +526,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
         # `results` is just passed on to the next callback
         yield self.master.data.updates.setBuildProperties(self.buildid, self)
 
-        defer.returnValue(results)
+        return results
 
     @defer.inlineCallbacks
     def _stepDone(self, results, step):
@@ -566,7 +563,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
             # force the results to retry if the connection was lost
             self.results = RETRY
             terminate = True
-        defer.returnValue(terminate)
+        return terminate
 
     def lostRemote(self, conn=None):
         # the worker went away. There are several possible reasons for this,
@@ -677,11 +674,16 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
                 self.workerforbuilder.worker.putInQuarantine()
             elif self.results != RETRY:
                 # This worker looks sane if status is neither retry or exception
-                self.workerforbuilder.worker.resetQuarantine()
+
+                # Avoid a race in case the build step reboot the worker
+                if self.workerforbuilder.worker is not None:
+                    self.workerforbuilder.worker.resetQuarantine()
 
             # mark the build as finished
             self.workerforbuilder.buildFinished()
             self.builder.buildFinished(self, self.workerforbuilder)
+
+            self._tryScheduleBuildsAfterLockUnlock(build_finished=True)
         except Exception:
             log.err(None, 'from finishing a build; this is a '
                           'serious error - please file a bug at http://buildbot.net')
@@ -689,10 +691,39 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
     def releaseLocks(self):
         if self.locks:
             log.msg("releaseLocks(%s): %s" % (self, self.locks))
+
         for lock, access in self.locks:
             if lock.isOwner(self, access):
                 lock.release(self, access)
 
+        self._tryScheduleBuildsAfterLockUnlock(locks_released=True)
+
+    def _tryScheduleBuildsAfterLockUnlock(self, locks_released=False,
+                                          build_finished=False):
+        # we need to inform the botmaster to attempt to schedule any pending
+        # build request if we released any locks. This is because buildrequest
+        # may be started for a completely unrelated builder and yet depend on
+        # a lock released by this build.
+        #
+        # TODO: the current approach is dumb as we just attempt to schedule
+        # all buildrequests. A much better idea would be to record the reason
+        # of why a buildrequest was not scheduled in the BuildRequestDistributor
+        # and then attempt to schedule only these buildrequests which may have
+        # had that reason resolved.
+
+        # this function is complicated by the fact that the botmaster must be
+        # informed only when all locks have been released and the actions in
+        # buildFinished have concluded. Since releaseLocks is called using
+        # eventually this may happen in any order.
+        self._locks_released = self._locks_released or locks_released
+        self._build_finished = self._build_finished or build_finished
+
+        if not self.locks:
+            return
+
+        if self._locks_released and self._build_finished:
+            self.builder.botmaster.maybeStartBuildsForAllBuilders()
+
     def getSummaryStatistic(self, name, summary_fn, initial_value=_sentinel):
         step_stats_list = [
             st.getStatistic(name)
@@ -705,7 +736,7 @@ class Build(properties.PropertiesMixin, WorkerAPICompatMixin):
     @defer.inlineCallbacks
     def getUrl(self):
         builder_id = yield self.getBuilderId()
-        defer.returnValue(getURLForBuild(self.master, builder_id, self.number))
+        return getURLForBuild(self.master, builder_id, self.number)
 
     def waitUntilFinished(self):
         return self.master.mq.waitUntilEvent(
