@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-from future.utils import itervalues
 from future.utils import string_types
 
 import re
@@ -30,7 +26,6 @@ from buildbot.process.properties import Properties
 from buildbot.reporters.mail import VALID_EMAIL_ADDR
 from buildbot.schedulers import base
 from buildbot.util import identifiers
-from buildbot.worker_transition import deprecatedWorkerModuleAttribute
 
 
 class ValidationError(ValueError):
@@ -41,11 +36,10 @@ class CollectedValidationError(ValueError):
 
     def __init__(self, errors):
         self.errors = errors
-        ValueError.__init__(
-            self, "\n".join([k + ":" + v for k, v in iteritems(errors)]))
+        super().__init__("\n".join([k + ":" + v for k, v in errors.items()]))
 
 
-class ValidationErrorCollector(object):
+class ValidationErrorCollector:
 
     def __init__(self):
         self.errors = {}
@@ -56,11 +50,11 @@ class ValidationErrorCollector(object):
         try:
             res = yield defer.maybeDeferred(fn, *args, **kwargs)
         except CollectedValidationError as e:
-            for error_name, e in iteritems(e.errors):
+            for error_name, e in e.errors.items():
                 self.errors[error_name] = e
         except ValueError as e:
             self.errors[name] = str(e)
-        defer.returnValue(res)
+        return res
 
     def maybeRaiseCollectedErrors(self):
         errors = self.errors
@@ -71,7 +65,7 @@ class ValidationErrorCollector(object):
 DefaultField = object()  # sentinel object to signal default behavior
 
 
-class BaseParameter(object):
+class BaseParameter:
 
     """
     BaseParameter provides a base implementation for property customization
@@ -269,7 +263,7 @@ class UserNameParameter(StringParameter):
     need_email = True
 
     def __init__(self, name="username", label="Your name:", **kw):
-        BaseParameter.__init__(self, name, label, **kw)
+        super().__init__(name, label, **kw)
 
     def parse_from_arg(self, s):
         if not s and not self.required:
@@ -354,14 +348,14 @@ class WorkerChoiceParameter(ChoiceStringParameter):
     strict = False
 
     def __init__(self, name='workername', **kwargs):
-        ChoiceStringParameter.__init__(self, name, **kwargs)
+        super().__init__(name, **kwargs)
 
     def updateFromKwargs(self, kwargs, **unused):
         workername = self.getFromKwargs(kwargs)
         if workername == self.anySentinel:
             # no preference, so don't set a parameter at all
             return
-        ChoiceStringParameter.updateFromKwargs(self, kwargs=kwargs, **unused)
+        super().updateFromKwargs(kwargs=kwargs, **unused)
 
     def getChoices(self, master, scheduler, buildername):
         if buildername is None:
@@ -376,10 +370,6 @@ class WorkerChoiceParameter(ChoiceStringParameter):
         return workernames
 
 
-deprecatedWorkerModuleAttribute(locals(), WorkerChoiceParameter,
-                                compat_name="BuildslaveChoiceParameter")
-
-
 class FileParameter(BaseParameter):
     """A parameter which allows to download a whole file and store it as a property or patch
     """
@@ -412,7 +402,7 @@ class NestedParameter(BaseParameter):
     columns = None
 
     def __init__(self, name, fields, **kwargs):
-        BaseParameter.__init__(self, fields=fields, name=name, **kwargs)
+        super().__init__(fields=fields, name=name, **kwargs)
         # reasonable defaults for the number of columns
         if self.columns is None:
             num_visible_fields = len(
@@ -429,7 +419,7 @@ class NestedParameter(BaseParameter):
         self.setParent(None)
 
     def setParent(self, parent):
-        BaseParameter.setParent(self, parent)
+        super().setParent(parent)
         for field in self.fields:  # pylint: disable=not-an-iterable
             field.setParent(self)
 
@@ -465,7 +455,7 @@ class NestedParameter(BaseParameter):
         d.update(kwargs[self.fullName])
 
     def getSpec(self):
-        ret = BaseParameter.getSpec(self)
+        ret = super().getSpec()
         # pylint: disable=not-an-iterable
         ret['fields'] = [field.getSpec() for field in self.fields]
         return ret
@@ -485,7 +475,7 @@ class AnyPropertyParameter(NestedParameter):
             StringParameter(name='name', label="Name:"),
             StringParameter(name='value', label="Value:"),
         ]
-        NestedParameter.__init__(self, name, label='', fields=fields, **kw)
+        super().__init__(name, label='', fields=fields, **kw)
 
     def getFromKwargs(self, kwargs):
         raise ValidationError(
@@ -556,14 +546,14 @@ class CodebaseParameter(NestedParameter):
 
         fields_dict = dict(branch=branch, revision=revision,
                            repository=repository, project=project)
-        for k, v in iteritems(fields_dict):
+        for k, v in fields_dict.items():
             if v is DefaultField:
                 v = StringParameter(name=k, label=k.capitalize() + ":")
             elif isinstance(v, string_types):
                 v = FixedParameter(name=k, default=v)
             fields_dict[k] = v
 
-        fields = [val for k, val in sorted(iteritems(fields_dict), key=lambda x: x[0]) if val]
+        fields = [val for k, val in sorted(fields_dict.items(), key=lambda x: x[0]) if val]
         if patch is not None:
             if patch.name != "patch":
                 config.error(
@@ -572,9 +562,9 @@ class CodebaseParameter(NestedParameter):
             if self.columns is None and 'columns' not in kwargs:
                 self.columns = 1
 
-        NestedParameter.__init__(self, name=name, label=label,
-                                 codebase=codebase,
-                                 fields=fields, **kwargs)
+        super().__init__(name=name, label=label,
+                         codebase=codebase,
+                         fields=fields, **kwargs)
 
     def createSourcestamp(self, properties, kwargs):
         # default, just return the things we put together
@@ -621,7 +611,7 @@ class PatchParameter(NestedParameter):
             kwargs.pop(field.name, field)
             for field in default_fields
         ]
-        NestedParameter.__init__(self, name, fields=fields, **kwargs)
+        super().__init__(name, fields=fields, **kwargs)
 
 
 class ForceScheduler(base.BaseScheduler):
@@ -740,11 +730,10 @@ class ForceScheduler(base.BaseScheduler):
             codebase_dict[codebase.codebase] = dict(
                 branch='', repository='', revision='')
 
-        base.BaseScheduler.__init__(self,
-                                    name=name,
-                                    builderNames=builderNames,
-                                    properties={},
-                                    codebases=codebase_dict)
+        super().__init__(name=name,
+                         builderNames=builderNames,
+                         properties={},
+                         codebases=codebase_dict)
 
         if properties:
             self.forcedProperties.extend(properties)
@@ -790,10 +779,10 @@ class ForceScheduler(base.BaseScheduler):
         changeids = [type(a) == int and a or a.number for a in changeids]
 
         real_properties = Properties()
-        for pname, pvalue in iteritems(properties):
+        for pname, pvalue in properties.items():
             real_properties.setProperty(pname, pvalue, "Force Build Form")
 
-        defer.returnValue((real_properties, changeids, sourcestamps))
+        return (real_properties, changeids, sourcestamps)
 
     @defer.inlineCallbacks
     def computeBuilderNames(self, builderNames=None, builderid=None):
@@ -806,7 +795,7 @@ class ForceScheduler(base.BaseScheduler):
         else:
             builderNames = sorted(
                 set(builderNames).intersection(self.builderNames))
-        defer.returnValue(builderNames)
+        return builderNames
 
     @defer.inlineCallbacks
     def force(self, owner, builderNames=None, builderid=None, **kwargs):
@@ -820,7 +809,7 @@ class ForceScheduler(base.BaseScheduler):
         # Currently the validation code expects all kwargs to be lists
         # I don't want to refactor that now so much sure we comply...
         kwargs = dict((k, [v]) if not isinstance(v, list) else (k, v)
-                      for k, v in iteritems(kwargs))
+                      for k, v in kwargs.items())
 
         # probably need to clean that out later as the IProperty is already a
         # validation mechanism
@@ -842,9 +831,9 @@ class ForceScheduler(base.BaseScheduler):
         r = self.reasonString % {'owner': owner, 'reason': reason}
 
         # turn sourcestamps into a list
-        for cb, ss in iteritems(sourcestamps):
+        for cb, ss in sourcestamps.items():
             ss['codebase'] = cb
-        sourcestamps = list(itervalues(sourcestamps))
+        sourcestamps = list(sourcestamps.values())
 
         # everything is validated, we can create our source stamp, and
         # buildrequest
@@ -855,4 +844,4 @@ class ForceScheduler(base.BaseScheduler):
             builderNames=builderNames,
         )
 
-        defer.returnValue(res)
+        return res
