@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import json
 import os
@@ -34,8 +32,6 @@ from buildbot.process.buildstep import BuildStep
 from buildbot.steps.worker import CompositeStepMixin
 from buildbot.util import flatten
 from buildbot.util.eventual import eventually
-from buildbot.worker_transition import WorkerAPICompatMixin
-from buildbot.worker_transition import reportDeprecatedWorkerNameUsage
 
 
 def makeStatusRemoteCommand(step, remote_command, args):
@@ -58,7 +54,7 @@ class _TransferBuildStep(BuildStep):
     flunkOnFailure = True
 
     def __init__(self, workdir=None, **buildstep_kwargs):
-        BuildStep.__init__(self, **buildstep_kwargs)
+        super().__init__(**buildstep_kwargs)
         self.workdir = workdir
 
     def runTransferCommand(self, cmd, writer=None):
@@ -88,33 +84,28 @@ class _TransferBuildStep(BuildStep):
             return d
 
 
-class FileUpload(_TransferBuildStep, WorkerAPICompatMixin):
+class FileUpload(_TransferBuildStep):
 
     name = 'upload'
 
-    renderables = ['workersrc', 'masterdest', 'url']
+    renderables = [
+        'masterdest',
+        'url',
+        'urlText',
+        'workersrc',
+    ]
 
     def __init__(self, workersrc=None, masterdest=None,
-                 workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
+                 workdir=None, maxsize=None, blocksize=256 * 1024, mode=None,
                  keepstamp=False, url=None, urlText=None,
-                 slavesrc=None,  # deprecated, use `workersrc` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavesrc is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavesrc' keyword argument is deprecated, "
-                "use 'workersrc' instead")
-            assert workersrc is None
-            workersrc = slavesrc
-
         # Emulate that first two arguments are positional.
         if workersrc is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
 
-        _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
+        super().__init__(workdir=workdir, **buildstep_kwargs)
 
         self.workersrc = workersrc
-        self._registerOldWorkerAttr("workersrc")
         self.masterdest = masterdest
         self.maxsize = maxsize
         self.blocksize = blocksize
@@ -130,7 +121,7 @@ class FileUpload(_TransferBuildStep, WorkerAPICompatMixin):
         log.msg("File '{}' upload finished with results {}".format(
             os.path.basename(self.workersrc), str(results)))
         self.step_status.setText(self.descriptionDone)
-        _TransferBuildStep.finished(self, results)
+        super().finished(results)
 
     def start(self):
         self.checkWorkerHasCommand("uploadFile")
@@ -189,7 +180,7 @@ class FileUpload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
+class DirectoryUpload(_TransferBuildStep):
 
     name = 'upload'
 
@@ -198,25 +189,15 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
     def __init__(self, workersrc=None, masterdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024,
                  compress=None, url=None, urlText=None,
-                 slavesrc=None,  # deprecated, use `workersrc` instead
                  **buildstep_kwargs
                  ):
-        # Deprecated API support.
-        if slavesrc is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavesrc' keyword argument is deprecated, "
-                "use 'workersrc' instead")
-            assert workersrc is None
-            workersrc = slavesrc
-
         # Emulate that first two arguments are positional.
         if workersrc is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
 
-        _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
+        super().__init__(workdir=workdir, **buildstep_kwargs)
 
         self.workersrc = workersrc
-        self._registerOldWorkerAttr("workersrc")
         self.masterdest = masterdest
         self.maxsize = maxsize
         self.blocksize = blocksize
@@ -272,8 +253,7 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
-                         CompositeStepMixin):
+class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
 
     name = 'upload'
     logEnviron = False
@@ -283,24 +263,15 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
     def __init__(self, workersrcs=None, masterdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024, glob=False,
                  mode=None, compress=None, keepstamp=False, url=None,
-                 slavesrcs=None,  # deprecated, use `workersrcs` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavesrcs is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavesrcs' keyword argument is deprecated, "
-                "use 'workersrcs' instead")
-            assert workersrcs is None
-            workersrcs = slavesrcs
 
         # Emulate that first two arguments are positional.
         if workersrcs is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
 
-        _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
+        super().__init__(workdir=workdir, **buildstep_kwargs)
 
         self.workersrcs = workersrcs
-        self._registerOldWorkerAttr("workersrcs")
         self.masterdest = masterdest
         self.maxsize = maxsize
         self.blocksize = blocksize
@@ -415,18 +386,18 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
                     os.path.join(self.workdir, source), abandonOnFailure=False) for source in sources
             ])
             results = [self.workerPathToMasterPath(p) for p in flatten(results)]
-            defer.returnValue(results)
+            return results
 
         @defer.inlineCallbacks
         def uploadSources(sources):
             if not sources:
-                defer.returnValue(SKIPPED)
+                return SKIPPED
             else:
                 for source in sources:
                     result = yield self.startUpload(source, masterdest)
                     if result == FAILURE:
-                        defer.returnValue(FAILURE)
-                defer.returnValue(SUCCESS)
+                        return FAILURE
+                return SUCCESS
 
         def logUpload(sources):
             log.msg("MultipleFileUpload started, from worker %r to master %r" %
@@ -454,11 +425,8 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
 
         d.addCallback(self.finished).addErrback(self.failed)
 
-    def finished(self, result):
-        return BuildStep.finished(self, result)
 
-
-class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
+class FileDownload(_TransferBuildStep):
 
     name = 'download'
 
@@ -466,25 +434,15 @@ class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
 
     def __init__(self, mastersrc, workerdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
 
-        _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
+        super().__init__(workdir=workdir, **buildstep_kwargs)
 
         self.mastersrc = mastersrc
         self.workerdest = workerdest
-        self._registerOldWorkerAttr("workerdest")
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
@@ -537,7 +495,7 @@ class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
+class StringDownload(_TransferBuildStep):
 
     name = 'string_download'
 
@@ -545,25 +503,15 @@ class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
 
     def __init__(self, s, workerdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
 
-        _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
+        super().__init__(workdir=workdir, **buildstep_kwargs)
 
         self.s = s
         self.workerdest = workerdest
-        self._registerOldWorkerAttr("workerdest")
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
@@ -607,21 +555,12 @@ class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class JSONStringDownload(StringDownload, WorkerAPICompatMixin):
+class JSONStringDownload(StringDownload):
 
     name = "json_download"
 
     def __init__(self, o, workerdest=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-                # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -629,25 +568,15 @@ class JSONStringDownload(StringDownload, WorkerAPICompatMixin):
         if 's' in buildstep_kwargs:
             del buildstep_kwargs['s']
         s = json.dumps(o)
-        StringDownload.__init__(
-            self, s=s, workerdest=workerdest, **buildstep_kwargs)
+        super().__init__(s=s, workerdest=workerdest, **buildstep_kwargs)
 
 
-class JSONPropertiesDownload(StringDownload, WorkerAPICompatMixin):
+class JSONPropertiesDownload(StringDownload):
 
     name = "json_properties_download"
 
     def __init__(self, workerdest=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 2 arguments")
@@ -655,8 +584,7 @@ class JSONPropertiesDownload(StringDownload, WorkerAPICompatMixin):
         self.super_class = StringDownload
         if 's' in buildstep_kwargs:
             del buildstep_kwargs['s']
-        StringDownload.__init__(
-            self, s=None, workerdest=workerdest, **buildstep_kwargs)
+        super().__init__(s=None, workerdest=workerdest, **buildstep_kwargs)
 
     def start(self):
         properties = self.build.getProperties()
