@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import datetime
 
 import dateutil.tz
@@ -63,7 +60,7 @@ Affected files ...
 """
 
 p4_describe_3 = \
-    u"""Change 3 by bob@testclient on 2006/04/13 21:51:39
+    """Change 3 by bob@testclient on 2006/04/13 21:51:39
 
 \tshort desc truncated because this is a long description.
 \tASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.
@@ -98,6 +95,18 @@ p4change = {
 }
 
 
+class FakeTransport:
+
+    def __init__(self):
+        self.msg = None
+
+    def write(self, msg):
+        self.msg = msg
+
+    def closeStdin(self):
+        pass
+
+
 class TestP4Poller(changesource.ChangeSourceMixin,
                    gpo.GetProcessOutputMixin,
                    config.ConfigErrorsMixin,
@@ -181,12 +190,12 @@ class TestP4Poller(changesource.ChangeSourceMixin,
         if changesAdded[1]['branch'] == 'branch_c':
             changesAdded[1:] = reversed(changesAdded[1:])
         self.assertEqual(self.master.data.updates.changesAdded, [{
-            'author': u'slamb',
-            'branch': u'trunk',
+            'author': 'slamb',
+            'branch': 'trunk',
             'category': None,
             'codebase': None,
-            'comments': u'creation',
-            'files': [u'whatbranch'],
+            'comments': 'creation',
+            'files': ['whatbranch'],
             'project': '',
             'properties': {},
             'repository': '',
@@ -195,14 +204,14 @@ class TestP4Poller(changesource.ChangeSourceMixin,
             'src': None,
             'when_timestamp': datetime2epoch(when1),
         }, {
-            'author': u'bob',
-            'branch': u'branch_b',
+            'author': 'bob',
+            'branch': 'branch_b',
             'category': None,
             'codebase': None,
             'comments':
-                u'short desc truncated because this is a long description.\n'
-                u'ASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.',
-            'files': [u'branch_b_file', u'whatbranch'],
+                'short desc truncated because this is a long description.\n'
+                'ASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.',
+            'files': ['branch_b_file', 'whatbranch'],
             'project': '',
             'properties': {},
             'repository': '',
@@ -211,14 +220,14 @@ class TestP4Poller(changesource.ChangeSourceMixin,
             'src': None,
             'when_timestamp': datetime2epoch(when2),
         }, {
-            'author': u'bob',
-            'branch': u'branch_c',
+            'author': 'bob',
+            'branch': 'branch_c',
             'category': None,
             'codebase': None,
             'comments':
-                u'short desc truncated because this is a long description.\n'
-                u'ASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.',
-            'files': [u'whatbranch'],
+                'short desc truncated because this is a long description.\n'
+                'ASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.',
+            'files': ['whatbranch'],
             'project': '',
             'properties': {},
             'repository': '',
@@ -318,17 +327,6 @@ class TestP4Poller(changesource.ChangeSourceMixin,
                        'changes', '-m', '1', '//depot/myproject/...').stdout(first_p4changes)
         )
 
-        class FakeTransport:
-
-            def __init__(self):
-                self.msg = None
-
-            def write(self, msg):
-                self.msg = msg
-
-            def closeStdin(self):
-                pass
-
         transport = FakeTransport()
 
         # p4poller uses only those arguments at the moment
@@ -347,6 +345,67 @@ class TestP4Poller(changesource.ChangeSourceMixin,
         self.assertEqual(
             self.changesource._ticket_passwd, 'TICKET_ID_GOES_HERE')
 
+    @defer.inlineCallbacks
+    def test_acquire_ticket_auth2(self):
+        self.attachChangeSource(
+            P4Source(p4port=None, p4user=None, p4passwd='pass',
+                     p4base='//depot/myproject/',
+                     split_file=lambda x: x.split('/', 1),
+                     use_tickets=True))
+        self.expectCommands(
+            gpo.Expect('p4', '-P', 'TICKET_ID_GOES_HERE',
+                       'changes', '-m', '1', '//depot/myproject/...').stdout(first_p4changes)
+        )
+
+        transport = FakeTransport()
+
+        # p4poller uses only those arguments at the moment
+        def spawnProcess(pp, cmd, argv, env):
+            self.assertEqual([cmd, argv],
+                             ['p4', [b'p4', b'login', b'-p']])
+            pp.makeConnection(transport)
+            self.assertEqual('pass\n', transport.msg)
+            pp.outReceived('Enter password:\nTICKET_ID_GOES_HERE\n')
+            so = error.ProcessDone(None)
+            pp.processEnded(failure.Failure(so))
+        self.patch(reactor, 'spawnProcess', spawnProcess)
+
+        yield self.changesource.poll()
+
+        self.assertEqual(
+            self.changesource._ticket_passwd, 'TICKET_ID_GOES_HERE')
+
+    @defer.inlineCallbacks
+    def test_acquire_ticket_auth2_fail(self):
+        self.attachChangeSource(
+            P4Source(p4port=None, p4user=None, p4passwd='pass',
+                     p4base='//depot/myproject/',
+                     split_file=lambda x: x.split('/', 1),
+                     use_tickets=True))
+        self.expectCommands(
+            gpo.Expect('p4', '-P', None,
+                       'changes', '-m', '1', '//depot/myproject/...').stdout(first_p4changes)
+        )
+
+        transport = FakeTransport()
+
+        # p4poller uses only those arguments at the moment
+        def spawnProcess(pp, cmd, argv, env):
+            self.assertEqual([cmd, argv],
+                             ['p4', [b'p4', b'login', b'-p']])
+            pp.makeConnection(transport)
+            self.assertEqual('pass\n', transport.msg)
+            pp.outReceived('Enter password:\n')
+            pp.errReceived("Password invalid.\n'auth-check' validation failed: Incorrect password!\n")
+            so = error.ProcessDone(status=1)
+            pp.processEnded(failure.Failure(so))
+        self.patch(reactor, 'spawnProcess', spawnProcess)
+
+        yield self.changesource.poll()
+
+        self.assertEqual(
+            self.changesource._ticket_passwd, None)
+
     @defer.inlineCallbacks
     def test_poll_split_file(self):
         """Make sure split file works on branch only changes"""
@@ -376,12 +435,12 @@ class TestP4Poller(changesource.ChangeSourceMixin,
 
         self.assertEqual(sorted(self.master.data.updates.changesAdded, key=changeKey),
             sorted([{
-            'author': u'mpatel',
-            'branch': u'branch_c',
+            'author': 'mpatel',
+            'branch': 'branch_c',
             'category': None,
             'codebase': None,
-            'comments': u'This is a multiline comment with tabs and spaces\n\nA list:\n  Item 1\n\tItem 2',
-            'files': [u'branch_c_file'],
+            'comments': 'This is a multiline comment with tabs and spaces\n\nA list:\n  Item 1\n\tItem 2',
+            'files': ['branch_c_file'],
             'project': '',
             'properties': {},
             'repository': '',
@@ -390,12 +449,12 @@ class TestP4Poller(changesource.ChangeSourceMixin,
             'src': None,
             'when_timestamp': datetime2epoch(when),
         }, {
-            'author': u'mpatel',
-            'branch': u'branch_b',
+            'author': 'mpatel',
+            'branch': 'branch_b',
             'category': None,
             'codebase': None,
-            'comments': u'This is a multiline comment with tabs and spaces\n\nA list:\n  Item 1\n\tItem 2',
-            'files': [u'branch_b_file'],
+            'comments': 'This is a multiline comment with tabs and spaces\n\nA list:\n  Item 1\n\tItem 2',
+            'files': ['branch_b_file'],
             'project': '',
             'properties': {},
             'repository': '',
@@ -436,8 +495,9 @@ class TestP4Poller(changesource.ChangeSourceMixin,
         self.assertAllCommandsRan()
 
     def test_resolveWho_callable(self):
-        self.assertRaisesConfigError("You need to provide a valid callable for resolvewho",
-                                     lambda: P4Source(resolvewho=None))
+        with self.assertRaisesConfigError(
+                "You need to provide a valid callable for resolvewho"):
+            P4Source(resolvewho=None)
 
 
 class TestSplit(unittest.TestCase):
