@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import operator
 
 from mock import Mock
@@ -42,10 +39,6 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.fake import fakeprotocol
 from buildbot.test.fake import worker
 from buildbot.test.fake.fakebuild import FakeBuildStatus
-from buildbot.test.util.warnings import assertNotProducesWarnings
-from buildbot.test.util.warnings import assertProducesWarning
-from buildbot.worker_transition import DeprecatedWorkerAPIWarning
-from buildbot.worker_transition import DeprecatedWorkerNameWarning
 
 
 class FakeChange:
@@ -91,10 +84,9 @@ class FakeRequest:
 class FakeBuildStep(BuildStep):
 
     def __init__(self):
-        BuildStep.__init__(
-            self, haltOnFailure=False, flunkOnWarnings=False, flunkOnFailure=True,
+        super().__init__(haltOnFailure=False, flunkOnWarnings=False, flunkOnFailure=True,
             warnOnWarnings=True, warnOnFailure=False, alwaysRun=False, name='fake')
-        self._summary = {u'step': u'result', u'build': u'build result'}
+        self._summary = {'step': 'result', 'build': 'build result'}
         self._expected_results = SUCCESS
 
     def run(self):
@@ -133,7 +125,7 @@ class FakeBuilder:
 
 
 @implementer(interfaces.IBuildStepFactory)
-class FakeStepFactory(object):
+class FakeStepFactory:
 
     """Fake step factory that just returns a fixed step object."""
 
@@ -149,7 +141,7 @@ class TestException(Exception):
 
 
 @implementer(interfaces.IBuildStepFactory)
-class FailingStepFactory(object):
+class FailingStepFactory:
 
     """Fake step factory that just returns a fixed step object."""
 
@@ -169,7 +161,7 @@ class _StepController():
 class _ControllableStep(BuildStep):
 
     def __init__(self):
-        BuildStep.__init__(self)
+        super().__init__()
         self._deferred = defer.Deferred()
 
     def run(self):
@@ -272,6 +264,7 @@ class TestBuild(unittest.TestCase):
         d.callback(False)
         self.assertEqual(b.results, RETRY)
 
+    @defer.inlineCallbacks
     def testAlwaysRunStepStopBuild(self):
         """Test that steps marked with alwaysRun=True still get run even if
         the build is stopped."""
@@ -306,16 +299,13 @@ class TestBuild(unittest.TestCase):
         step2.startStep = startStep2
         step1.stepDone = lambda: False
 
-        d = b.startBuild(FakeBuildStatus(), self.workerforbuilder)
+        yield b.startBuild(FakeBuildStatus(), self.workerforbuilder)
 
-        def check(ign):
-            self.assertEqual(b.results, CANCELLED)
-            self.assertIn('stop it', step1.interrupted)
-            self.assertTrue(step2Started[0])
-        d.addCallback(check)
-        return d
+        self.assertEqual(b.results, CANCELLED)
+        self.assertIn('stop it', step1.interrupted)
+        self.assertTrue(step2Started[0])
 
-    def testBuildcanStartWithWorkerForBuilder(self):
+    def testBuild_canAcquireLocks(self):
         b = self.build
 
         workerforbuilder1 = Mock()
@@ -329,39 +319,41 @@ class TestBuild(unittest.TestCase):
         # state/memory)
         lock_list = [(real_lock, counting_access)]
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
 
-        worker_lock_1 = real_lock.getLock(workerforbuilder1.worker)
-        worker_lock_2 = real_lock.getLock(workerforbuilder2.worker)
+        worker_lock_1 = real_lock.getLockForWorker(
+            workerforbuilder1.worker.workername)
+        worker_lock_2 = real_lock.getLockForWorker(
+            workerforbuilder2.worker.workername)
 
         # then have workerforbuilder2 claim its lock:
         worker_lock_2.claim(workerforbuilder2, counting_access)
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         worker_lock_2.release(workerforbuilder2, counting_access)
 
         # then have workerforbuilder1 claim its lock:
         worker_lock_1.claim(workerforbuilder1, counting_access)
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         worker_lock_1.release(workerforbuilder1, counting_access)
 
     def testBuilddirPropType(self):
@@ -392,7 +384,7 @@ class TestBuild(unittest.TestCase):
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
         real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLock(self.workerforbuilder.worker)
+            .getLockForWorker(self.workerforbuilder.worker.workername)
 
         def claim(owner, access):
             claimCount[0] += 1
@@ -428,7 +420,8 @@ class TestBuild(unittest.TestCase):
 
         lock = WorkerLock('lock', 2)
         claimLog = []
-        realLock = self.master.botmaster.getLockByID(lock).getLock(self.worker)
+        realLock = self.master.botmaster.getLockByID(lock) \
+            .getLockForWorker(self.worker.workername)
 
         def claim(owner, access):
             claimLog.append(owner)
@@ -469,7 +462,7 @@ class TestBuild(unittest.TestCase):
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
         real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLock(self.workerforbuilder.worker)
+            .getLockForWorker(self.workerforbuilder.worker.workername)
 
         def claim(owner, access):
             claimCount[0] += 1
@@ -496,7 +489,7 @@ class TestBuild(unittest.TestCase):
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
         real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLock(self.workerforbuilder.worker)
+            .getLockForWorker(self.workerforbuilder.worker.workername)
         b.setLocks([lock_access])
 
         step = FakeBuildStep()
@@ -523,7 +516,7 @@ class TestBuild(unittest.TestCase):
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
         real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLock(self.workerforbuilder.worker)
+            .getLockForWorker(self.workerforbuilder.worker.workername)
         b.setLocks([lock_access])
 
         step = FakeBuildStep()
@@ -553,7 +546,7 @@ class TestBuild(unittest.TestCase):
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
         real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLock(self.workerforbuilder.worker)
+            .getLockForWorker(self.workerforbuilder.worker.workername)
 
         step = LoggingBuildStep(locks=[lock_access])
         b.setStepFactories([FakeStepFactory(step)])
@@ -721,7 +714,7 @@ class TestBuild(unittest.TestCase):
         res = yield b._flushProperties(result)
         self.assertEqual(res, result)
         self.assertEqual(self.master.data.updates.properties,
-                         [(43, u'foo', 'bar', u'test')])
+                         [(43, 'foo', 'bar', 'test')])
 
     def create_fake_steps(self, names):
         steps = []
@@ -1138,72 +1131,3 @@ class TestBuildProperties(unittest.TestCase):
     def test_render(self):
         self.build.render("xyz")
         self.properties.render.assert_called_with("xyz")
-
-    def test_getWorkerName_old_api(self):
-        @implementer(interfaces.IProperties)
-        class FakeProperties(Mock):
-            pass
-        import posixpath
-
-        r = FakeRequest()
-        build = Build([r])
-        build.properties = FakeProperties()
-        build.builder = FakeBuilder(self.master)
-        build.build_status = FakeBuildStatus()
-
-        w = worker.FakeWorker(self.master)
-        w.path_module = posixpath
-        w.properties = FakeProperties()
-        w.workername = 'worker name'
-        w.worker_basedir = None
-
-        workerforbuilder = Mock(name='workerforbuilder')
-        workerforbuilder.worker = w
-
-        build.workerforbuilder = workerforbuilder
-
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = build.getWorkerName()
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'getSlaveName' method is deprecated"):
-            old = build.getSlaveName()
-
-        self.assertEqual(old, 'worker name')
-        self.assertIdentical(new, old)
-
-    def test_workername_old_api(self):
-        @implementer(interfaces.IProperties)
-        class FakeProperties(Mock):
-            pass
-
-        import posixpath
-
-        r = FakeRequest()
-        build = Build([r])
-        build.properties = FakeProperties()
-        build.builder = FakeBuilder(self.master)
-        build.build_status = FakeBuildStatus()
-
-        w = worker.FakeWorker(self.master)
-        w.path_module = posixpath
-        w.properties = FakeProperties()
-        w.workername = 'worker name'
-        w.worker_basedir = None
-
-        workerforbuilder = Mock(name='workerforbuilder')
-        workerforbuilder.worker = w
-
-        build.setupWorkerForBuilder(workerforbuilder)
-
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = build.workername
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavename' attribute is deprecated"):
-            old = build.slavename
-
-        self.assertEqual(old, 'worker name')
-        self.assertIdentical(new, old)
