@@ -13,11 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.builtins import range
-from future.utils import iteritems
-
 import mock
 
 from twisted.internet import defer
@@ -46,16 +41,6 @@ def nth_worker(n):
     return pick_nth_by_name
 
 
-class SkipWorkerThatCantGetLock(buildrequestdistributor.BasicBuildChooser):
-
-    """This class disables the 'rejectedWorkers' feature"""
-
-    def __init__(self, *args, **kwargs):
-        buildrequestdistributor.BasicBuildChooser.__init__(
-            self, *args, **kwargs)
-        self.rejectedWorkers = None  # disable this feature
-
-
 class TestBRDBase(unittest.TestCase):
 
     def setUp(self):
@@ -75,19 +60,6 @@ class TestBRDBase(unittest.TestCase):
         self.brd.parent = self.botmaster
         self.brd.startService()
 
-        # TODO: this is a terrible way to detect the "end" of the test -
-        # it regularly completes too early after a simple modification of
-        # a test.  Is there a better way?
-        self.quiet_deferred = defer.Deferred()
-
-        def _quiet():
-            if self.quiet_deferred:
-                d, self.quiet_deferred = self.quiet_deferred, None
-                d.callback(None)
-            else:
-                self.fail("loop has already gone quiet once")
-        self.brd._quiet = _quiet
-
         # a collection of rows that would otherwise clutter up every test
         self.base_rows = [
             fakedb.SourceStamp(id=21),
@@ -113,7 +85,7 @@ class TestBRDBase(unittest.TestCase):
 
     def addWorkers(self, workerforbuilders):
         """C{workerforbuilders} maps name : available"""
-        for name, avail in iteritems(workerforbuilders):
+        for name, avail in workerforbuilders.items():
             wfb = mock.Mock(spec=['isAvailable'], name=name)
             wfb.name = name
             wfb.isAvailable.return_value = avail
@@ -138,7 +110,6 @@ class TestBRDBase(unittest.TestCase):
             reactor.callLater(0, d.callback, True)
             return d
         bldr.maybeStartBuild = maybeStartBuild
-        bldr.canStartWithWorkerForBuilder = lambda _, __: True
         bldr.getCollapseRequestsFn = lambda: False
 
         bldr.workers = []
@@ -156,7 +127,7 @@ class TestBRDBase(unittest.TestCase):
             return not can or can(*args)
         bldr.canStartBuild = canStartBuild
 
-        defer.returnValue(bldr)
+        return bldr
 
     @defer.inlineCallbacks
     def addBuilders(self, names):
@@ -198,17 +169,17 @@ class Test(TestBRDBase):
 
     # tests
 
+    @defer.inlineCallbacks
     def test_maybeStartBuildsOn_simple(self):
         self.useMock_maybeStartBuildsOnBuilder()
         self.addBuilders(['bldr1'])
-        self.brd.maybeStartBuildsOn(['bldr1'])
+        yield self.brd.maybeStartBuildsOn(['bldr1'])
 
-        def check(_):
-            self.assertEqual(self.maybeStartBuildsOnBuilder_calls, ['bldr1'])
-            self.checkAllCleanedUp()
-        self.quiet_deferred.addCallback(check)
-        return self.quiet_deferred
+        yield self.brd._waitForFinish()
+        self.assertEqual(self.maybeStartBuildsOnBuilder_calls, ['bldr1'])
+        self.checkAllCleanedUp()
 
+    @defer.inlineCallbacks
     def test_maybeStartBuildsOn_parallel(self):
         # test 15 "parallel" invocations of maybeStartBuildsOn, with a
         # _sortBuilders that takes a while.  This is a regression test for bug
@@ -229,66 +200,62 @@ class Test(TestBRDBase):
         self.useMock_maybeStartBuildsOnBuilder()
         self.addBuilders(builders)
         for bldr in builders:
-            self.brd.maybeStartBuildsOn([bldr])
+            yield self.brd.maybeStartBuildsOn([bldr])
 
-        def check(_):
-            self.assertEqual(self.maybeStartBuildsOnBuilder_calls, builders)
-            self.checkAllCleanedUp()
-        self.quiet_deferred.addCallback(check)
-        return self.quiet_deferred
+        yield self.brd._waitForFinish()
+        self.assertEqual(self.maybeStartBuildsOnBuilder_calls, builders)
+        self.checkAllCleanedUp()
 
+    @defer.inlineCallbacks
     def test_maybeStartBuildsOn_exception(self):
         self.addBuilders(['bldr1'])
 
         def _maybeStartBuildsOnBuilder(n):
-            # fail slowly, so that the activity loop doesn't go quiet too soon
+            # fail slowly, so that the activity loop doesn't exit too soon
             d = defer.Deferred()
             reactor.callLater(0,
                               d.errback, failure.Failure(RuntimeError("oh noes")))
             return d
         self.brd._maybeStartBuildsOnBuilder = _maybeStartBuildsOnBuilder
 
-        self.brd.maybeStartBuildsOn(['bldr1'])
+        yield self.brd.maybeStartBuildsOn(['bldr1'])
 
-        def check(_):
-            self.assertEqual(len(self.flushLoggedErrors(RuntimeError)), 1)
-            self.checkAllCleanedUp()
-        self.quiet_deferred.addCallback(check)
-        return self.quiet_deferred
+        yield self.brd._waitForFinish()
+        self.assertEqual(len(self.flushLoggedErrors(RuntimeError)), 1)
+        self.checkAllCleanedUp()
 
+    @defer.inlineCallbacks
     def test_maybeStartBuildsOn_collapsing(self):
         self.useMock_maybeStartBuildsOnBuilder()
         self.addBuilders(['bldr1', 'bldr2', 'bldr3'])
-        self.brd.maybeStartBuildsOn(['bldr3'])
-        self.brd.maybeStartBuildsOn(['bldr2', 'bldr1'])
-        self.brd.maybeStartBuildsOn(['bldr4'])  # should be ignored
-        self.brd.maybeStartBuildsOn(['bldr2'])  # already queued - ignored
-        self.brd.maybeStartBuildsOn(['bldr3', 'bldr2'])
+        yield self.brd.maybeStartBuildsOn(['bldr3'])
+        yield self.brd.maybeStartBuildsOn(['bldr2', 'bldr1'])
+        yield self.brd.maybeStartBuildsOn(['bldr4'])  # should be ignored
+        yield self.brd.maybeStartBuildsOn(['bldr2'])  # already queued - ignored
+        yield self.brd.maybeStartBuildsOn(['bldr3', 'bldr2'])
 
-        def check(_):
-            # bldr3 gets invoked twice, since it's considered to have started
-            # already when the first call to maybeStartBuildsOn returns
-            self.assertEqual(self.maybeStartBuildsOnBuilder_calls,
-                             ['bldr3', 'bldr1', 'bldr2', 'bldr3'])
-            self.checkAllCleanedUp()
-        self.quiet_deferred.addCallback(check)
-        return self.quiet_deferred
+        yield self.brd._waitForFinish()
+        # bldr3 gets invoked twice, since it's considered to have started
+        # already when the first call to maybeStartBuildsOn returns
+        self.assertEqual(self.maybeStartBuildsOnBuilder_calls,
+                         ['bldr3', 'bldr1', 'bldr2', 'bldr3'])
+        self.checkAllCleanedUp()
 
+    @defer.inlineCallbacks
     def test_maybeStartBuildsOn_builders_missing(self):
         self.useMock_maybeStartBuildsOnBuilder()
         self.addBuilders(['bldr1', 'bldr2', 'bldr3'])
-        self.brd.maybeStartBuildsOn(['bldr1', 'bldr2', 'bldr3'])
+        yield self.brd.maybeStartBuildsOn(['bldr1', 'bldr2', 'bldr3'])
         # bldr1 is already run, so surreptitiously remove the other
         # two - nothing should crash, but the builders should not run
         self.removeBuilder('bldr2')
         self.removeBuilder('bldr3')
 
-        def check(_):
-            self.assertEqual(self.maybeStartBuildsOnBuilder_calls, ['bldr1'])
-            self.checkAllCleanedUp()
-        self.quiet_deferred.addCallback(check)
-        return self.quiet_deferred
+        yield self.brd._waitForFinish()
+        self.assertEqual(self.maybeStartBuildsOnBuilder_calls, ['bldr1'])
+        self.checkAllCleanedUp()
 
+    @defer.inlineCallbacks
     def do_test_sortBuilders(self, prioritizeBuilders, oldestRequestTimes,
                              expected, returnDeferred=False):
         self.useMock_maybeStartBuildsOnBuilder()
@@ -300,18 +267,15 @@ class Test(TestBRDBase):
                 return lambda: defer.succeed(t)
             return lambda: t
 
-        for n, t in iteritems(oldestRequestTimes):
+        for n, t in oldestRequestTimes.items():
             if t is not None:
                 t = epoch2datetime(t)
             self.builders[n].getOldestRequestTime = mklambda(t)
 
-        d = self.brd._sortBuilders(list(oldestRequestTimes))
+        result = yield self.brd._sortBuilders(list(oldestRequestTimes))
 
-        def check(result):
-            self.assertEqual(result, expected)
-            self.checkAllCleanedUp()
-        d.addCallback(check)
-        return d
+        self.assertEqual(result, expected)
+        self.checkAllCleanedUp()
 
     def test_sortBuilders_default_sync(self):
         return self.do_test_sortBuilders(None,  # use the default sort
@@ -348,6 +312,7 @@ class Test(TestBRDBase):
                                          dict(bldr1=1, bldr2=1, bldr3=1),
                                          ['bldr1', 'bldr2', 'bldr3'])
 
+    @defer.inlineCallbacks
     def test_sortBuilders_custom_exception(self):
         self.useMock_maybeStartBuildsOnBuilder()
         self.addBuilders(['x', 'y'])
@@ -358,16 +323,14 @@ class Test(TestBRDBase):
 
         # expect to get the builders back in the same order in the event of an
         # exception
-        d = self.brd._sortBuilders(['y', 'x'])
+        result = yield self.brd._sortBuilders(['y', 'x'])
 
-        def check(result):
-            self.assertEqual(result, ['y', 'x'])
+        self.assertEqual(result, ['y', 'x'])
 
-            # and expect the exception to be logged
-            self.assertEqual(len(self.flushLoggedErrors(RuntimeError)), 1)
-        d.addCallback(check)
-        return d
+        # and expect the exception to be logged
+        self.assertEqual(len(self.flushLoggedErrors(RuntimeError)), 1)
 
+    @defer.inlineCallbacks
     def test_stopService(self):
         # check that stopService waits for a builder run to complete, but does not
         # allow a subsequent run to start
@@ -390,20 +353,19 @@ class Test(TestBRDBase):
 
         # start both builds; A should start and complete *before* the service stops,
         # and B should not run.
-        self.brd.maybeStartBuildsOn(['A', 'B'])
+        yield self.brd.maybeStartBuildsOn(['A', 'B'])
 
-        def check(_):
-            self.assertEqual(self.maybeStartBuildsOnBuilder_calls,
-                             ['A', 'finished', '(stopped)'])
-        self.quiet_deferred.addCallback(check)
-        return self.quiet_deferred
+        yield self.brd._waitForFinish()
+
+        self.assertEqual(self.maybeStartBuildsOnBuilder_calls,
+                         ['A', 'finished', '(stopped)'])
 
 
 class TestMaybeStartBuilds(TestBRDBase):
 
     @defer.inlineCallbacks
     def setUp(self):
-        TestBRDBase.setUp(self)
+        super().setUp()
 
         self.startedBuilds = []
 
@@ -514,13 +476,6 @@ class TestMaybeStartBuilds(TestBRDBase):
 
         self.bldr.config.nextWorker = nth_worker(-1)
 
-        workers_attempted = []
-
-        def _canStartWithWorkerForBuilder(workerforbuilder, buildrequests):
-            workers_attempted.append(workerforbuilder.name)
-            return True
-        self.bldr.canStartWithWorkerForBuilder = _canStartWithWorkerForBuilder
-
         pairs_tested = []
 
         def _canStartBuild(worker, breq):
@@ -547,9 +502,6 @@ class TestMaybeStartBuilds(TestBRDBase):
                                                      exp_claims=[10, 11], exp_builds=[
                                                          ('test-worker1', [10]), ('test-worker3', [11])])
 
-        self.assertEqual(
-            workers_attempted, ['test-worker3', 'test-worker2', 'test-worker1'])
-
         # we expect brids in order (10-11-12),
         # with each searched in reverse order of workers (3-2-1) available (due
         # to nth_worker(-1))
@@ -560,25 +512,11 @@ class TestMaybeStartBuilds(TestBRDBase):
             ('test-worker3', 11),
             ('test-worker2', 12)])
 
-    @mock.patch('buildbot.process.buildrequestdistributor.BuildRequestDistributor.BuildChooser',
-                SkipWorkerThatCantGetLock)
     @defer.inlineCallbacks
     def test_limited_by_canStartBuild_deferreds(self):
-        """Another variant that:
-         * returns Deferred types,
-         * use 'canStartWithWorkerForBuilder' to reject one of the workers
-         * patch using SkipWorkerThatCantGetLock to disable the 'rejectedWorkers' feature"""
-
+        # Another variant that returns Deferred types,
         self.bldr.config.nextWorker = nth_worker(-1)
 
-        workers_attempted = []
-
-        def _canStartWithWorkerForBuilder(workerforbuilder, buildrequests):
-            workers_attempted.append(workerforbuilder.name)
-            allowed = workerforbuilder.name in ['test-worker2', 'test-worker1']
-            return defer.succeed(allowed)   # a deferred here!
-        self.bldr.canStartWithWorkerForBuilder = _canStartWithWorkerForBuilder
-
         pairs_tested = []
 
         def _canStartBuild(worker, breq):
@@ -602,43 +540,21 @@ class TestMaybeStartBuilds(TestBRDBase):
                                 submitted_at=140000),
         ]
         yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10], exp_builds=[('test-worker1', [10])])
-
-        self.assertEqual(
-            workers_attempted, ['test-worker3', 'test-worker2', 'test-worker1'])
+                                                     exp_claims=[10, 11],
+                                                     exp_builds=[
+                                                         ('test-worker1', [10]),
+                                                         ('test-worker3', [11])
+                                                     ])
 
         # we expect brids in order (10-11-12),
-        # with worker3 skipped, and worker2 unable to pair
+        # with worker2 unable to pair
         self.assertEqual(pairs_tested, [
+            ('test-worker3', 10),
             ('test-worker2', 10),
             ('test-worker1', 10),
-            ('test-worker2', 11),
+            ('test-worker3', 11),
             ('test-worker2', 12)])
 
-    @defer.inlineCallbacks
-    def test_limited_by_canStartWithWorkerForBuilder(self):
-        self.bldr.config.nextWorker = nth_worker(-1)
-
-        workers_attempted = []
-
-        def _canStartWithWorkerForBuilder(workerforbuilder, buildrequests):
-            workers_attempted.append(workerforbuilder.name)
-            return (workerforbuilder.name == 'test-worker3')
-        self.bldr.canStartWithWorkerForBuilder = _canStartWithWorkerForBuilder
-        self.addWorkers(
-            {'test-worker1': 0, 'test-worker2': 1, 'test-worker3': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=10, buildsetid=11, builderid=77,
-                                submitted_at=130000),
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77,
-                                submitted_at=135000),
-        ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10, 11], exp_builds=[
-                                                         ('test-worker3', [10]), ('test-worker2', [11])])
-
-        self.assertEqual(workers_attempted, ['test-worker3', 'test-worker2'])
-
     @defer.inlineCallbacks
     def test_unlimited(self):
         self.bldr.config.nextWorker = nth_worker(-1)
