@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import mock
 
 from twisted.internet import defer
@@ -75,11 +71,11 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
     # tests
 
     def test_constructor_builderNames(self):
-        self.assertRaises(config.ConfigErrors,
-                          lambda: self.makeScheduler(builderNames='xxx'))
+        with self.assertRaises(config.ConfigErrors):
+            self.makeScheduler(builderNames='xxx')
 
     def test_constructor_builderNames_unicode(self):
-        self.makeScheduler(builderNames=[u'a'])
+        self.makeScheduler(builderNames=['a'])
 
     def test_constructor_builderNames_renderable(self):
         @properties.renderer
@@ -89,7 +85,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
 
     def test_constructor_codebases_valid(self):
         codebases = {"codebase1":
-                     {"repository": u"", "branch": u"", "revision": u""}}
+                     {"repository": "", "branch": "", "revision": ""}}
         self.makeScheduler(codebases=codebases)
 
     def test_constructor_codebases_valid_list(self):
@@ -99,8 +95,8 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
     def test_constructor_codebases_invalid(self):
         # scheduler only accepts codebases with at least repository set
         codebases = {"codebase1": {"dictionary": "", "that": "", "fails": ""}}
-        self.assertRaises(config.ConfigErrors,
-                          lambda: self.makeScheduler(codebases=codebases))
+        with self.assertRaises(config.ConfigErrors):
+            self.makeScheduler(codebases=codebases)
 
     @defer.inlineCallbacks
     def test_getCodebaseDict(self):
@@ -304,7 +300,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
         sched = self.makeScheduler(name='n', builderNames=['b'],
                                    codebases=codebases)
         bsid, brids = yield sched.addBuildsetForSourceStampsWithDefaults(
-            reason=u'power', sourcestamps=sourcestamps, waited_for=False)
+            reason='power', sourcestamps=sourcestamps, waited_for=False)
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
         call = self.master.data.updates.addBuildset.mock_calls[0]
 
@@ -388,7 +384,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
         self.db.insertTestData([
             fakedb.Change(changeid=13, sourcestampid=234),
         ])
-        bsid, brids = yield sched.addBuildsetForChanges(reason=u'power',
+        bsid, brids = yield sched.addBuildsetForChanges(reason='power',
                                                         waited_for=False, changeids=[13])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
         self.master.data.updates.addBuildset.assert_called_with(
@@ -396,10 +392,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1],
             external_idstring=None,
             properties={
-                u'scheduler': ('n', u'Scheduler'),
+                'scheduler': ('n', 'Scheduler'),
             },
-            reason=u'power',
-            scheduler=u'n',
+            reason='power',
+            scheduler='n',
             sourcestamps=[234])
 
     @defer.inlineCallbacks
@@ -408,7 +404,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
         self.db.insertTestData([
             fakedb.Change(changeid=14, sourcestampid=234),
         ])
-        bsid, brids = yield sched.addBuildsetForChanges(reason=u'downstream',
+        bsid, brids = yield sched.addBuildsetForChanges(reason='downstream',
                                                         waited_for=False, changeids=[14])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
         self.master.data.updates.addBuildset.assert_called_with(
@@ -416,10 +412,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1],
             external_idstring=None,
             properties={
-                u'scheduler': ('n', u'Scheduler'),
+                'scheduler': ('n', 'Scheduler'),
             },
-            reason=u'downstream',
-            scheduler=u'n',
+            reason='downstream',
+            scheduler='n',
             sourcestamps=[234])
 
     @defer.inlineCallbacks
@@ -437,7 +433,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
 
         # note that the changeids are given out of order here; it should still
         # use the most recent
-        bsid, brids = yield sched.addBuildsetForChanges(reason=u'power',
+        bsid, brids = yield sched.addBuildsetForChanges(reason='power',
                                                         waited_for=False, changeids=[14, 15, 13])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
         self.master.data.updates.addBuildset.assert_called_with(
@@ -445,10 +441,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1, 2],
             external_idstring=None,
             properties={
-                u'scheduler': ('n', u'Scheduler'),
+                'scheduler': ('n', 'Scheduler'),
             },
-            reason=u'power',
-            scheduler=u'n',
+            reason='power',
+            scheduler='n',
             sourcestamps=[10])  # sourcestampid from greatest changeid
 
     @defer.inlineCallbacks
@@ -482,7 +478,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
 
         # note that the changeids are given out of order here; it should still
         # use the most recent for each codebase
-        bsid, brids = yield sched.addBuildsetForChanges(reason=u'power',
+        bsid, brids = yield sched.addBuildsetForChanges(reason='power',
                                                         waited_for=True, changeids=[14, 12, 17, 16, 13, 15])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
 
@@ -490,10 +486,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             waited_for=True,
             builderids=[1, 2],
             external_idstring=None,
-            reason=u'power',
-            scheduler=u'n',
+            reason='power',
+            scheduler='n',
             properties={
-                u'scheduler': ('n', u'Scheduler'),
+                'scheduler': ('n', 'Scheduler'),
             },
             sourcestamps=[914,
                           917,
@@ -507,15 +503,15 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def test_addBuildsetForSourceStamp(self):
         sched = self.makeScheduler(name='n', builderNames=['b'])
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'whynot',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='whynot',
                                                              waited_for=False, sourcestamps=[91, {'sourcestamp': True}])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
         self.master.data.updates.addBuildset.assert_called_with(
             waited_for=False,
             builderids=[1],
             external_idstring=None,
-            reason=u'whynot',
-            scheduler=u'n',
+            reason='whynot',
+            scheduler='n',
             properties={
                 'scheduler': ('n', 'Scheduler'),
             },
@@ -524,7 +520,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def test_addBuildsetForSourceStamp_explicit_builderNames(self):
         sched = self.makeScheduler(name='n', builderNames=['b', 'x', 'y'])
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'whynot',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='whynot',
                                                              waited_for=True,
                                                              sourcestamps=[
                                                                  91, {'sourcestamp': True}],
@@ -534,8 +530,8 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             waited_for=True,
             builderids=[2, 3],
             external_idstring=None,
-            reason=u'whynot',
-            scheduler=u'n',
+            reason='whynot',
+            scheduler='n',
             properties={
                 'scheduler': ('n', 'Scheduler'),
             },
@@ -545,7 +541,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
     def test_addBuildsetForSourceStamp_properties(self):
         props = properties.Properties(xxx="yyy")
         sched = self.makeScheduler(name='n', builderNames=['b'])
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'whynot',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='whynot',
                                                              waited_for=False,
                                                              sourcestamps=[91], properties=props)
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
@@ -554,10 +550,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1],
             external_idstring=None,
             properties={
-                u'xxx': ('yyy', u'TEST'),
-                u'scheduler': (u'n', u'Scheduler')},
-            reason=u'whynot',
-            scheduler=u'n',
+                'xxx': ('yyy', 'TEST'),
+                'scheduler': ('n', 'Scheduler')},
+            reason='whynot',
+            scheduler='n',
             sourcestamps=[91])
 
     @defer.inlineCallbacks
@@ -571,7 +567,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
                                   property_value='["pink","Change"]'),
         ])
 
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'whynot',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='whynot',
                                                              waited_for=False,
                                                              sourcestamps=[98])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
@@ -580,10 +576,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1, 2],
             external_idstring=None,
             properties={
-                u'scheduler': (u'testsched', u'Scheduler'),
-                u'color': (u'pink', u'Change')},
-            reason=u'whynot',
-            scheduler=u'testsched',
+                'scheduler': ('testsched', 'Scheduler'),
+                'color': ('pink', 'Change')},
+            reason='whynot',
+            scheduler='testsched',
             sourcestamps=[98])
 
     @defer.inlineCallbacks
@@ -607,7 +603,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             fakedb.Change(changeid=26, sourcestampid=99, branch='unstable'),
         ])
 
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'whynot',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='whynot',
                                                              waited_for=False,
                                                              sourcestamps=[98])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
@@ -616,12 +612,12 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[3],
             external_idstring=None,
             properties={
-                u'scheduler': (u'n', u'Scheduler')},
-            reason=u'whynot',
-            scheduler=u'n',
+                'scheduler': ('n', 'Scheduler')},
+            reason='whynot',
+            scheduler='n',
             sourcestamps=[98])
 
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'because',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='because',
                                                              waited_for=False,
                                                              sourcestamps=[99])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
@@ -630,9 +626,9 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1, 2],
             external_idstring=None,
             properties={
-                u'scheduler': (u'n', u'Scheduler')},
-            reason=u'because',
-            scheduler=u'n',
+                'scheduler': ('n', 'Scheduler')},
+            reason='because',
+            scheduler='n',
             sourcestamps=[99])
 
     @defer.inlineCallbacks
@@ -650,7 +646,7 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
                                   property_value='["c","Change"]'),
         ])
 
-        bsid, brids = yield sched.addBuildsetForSourceStamps(reason=u'whynot',
+        bsid, brids = yield sched.addBuildsetForSourceStamps(reason='whynot',
                                                              waited_for=False,
                                                              sourcestamps=[98])
         self.assertEqual((bsid, brids), self.exp_bsid_brids)
@@ -659,10 +655,10 @@ class BaseScheduler(scheduler.SchedulerMixin, unittest.TestCase):
             builderids=[1, 2, 3],
             external_idstring=None,
             properties={
-                u'scheduler': (u'n', u'Scheduler'),
-                u'extra_builder': (u'c', u'Change')},
-            reason=u'whynot',
-            scheduler=u'n',
+                'scheduler': ('n', 'Scheduler'),
+                'extra_builder': ('c', 'Change')},
+            reason='whynot',
+            scheduler='n',
             sourcestamps=[98])
 
     def test_signature_addBuildsetForChanges(self):
