@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import mock
 
@@ -37,7 +35,7 @@ from buildbot.test.util import steps
 
 class TestStatsServicesBase(unittest.TestCase):
 
-    BUILDER_NAMES = [u'builder1', u'builder2']
+    BUILDER_NAMES = ['builder1', 'builder2']
     BUILDER_IDS = [1, 2]
 
     def setUp(self):
@@ -88,9 +86,8 @@ class TestStatsServicesConfiguration(TestStatsServicesBase):
     def test_bad_configuration(self):
         # Reconfigure with a bad configuration.
         new_storage_backends = [mock.Mock()]
-        self.assertRaises(TypeError,
-                          self.stats_service.reconfigService,
-                          new_storage_backends)
+        with self.assertRaises(TypeError):
+            self.stats_service.reconfigService(new_storage_backends)
 
     def checkEqual(self, new_storage_backends):
         # Check whether the new_storage_backends was set in reconfigService
@@ -116,10 +113,9 @@ class TestInfluxDB(TestStatsServicesBase, logging.LoggingMixin):
             # consume it somehow to please pylint
             [influxdb]
         except ImportError:
-            self.assertRaises(config.ConfigErrors,
-                              lambda: InfluxStorageService(
-                                  "fake_url", "fake_port", "fake_user", "fake_password",
-                                  "fake_db", captures))
+            with self.assertRaises(config.ConfigErrors):
+                InfluxStorageService("fake_url", "fake_port", "fake_user",
+                                     "fake_password", "fake_db", captures)
 
         # if instead influxdb is installed, then initialize it - no errors
         # should be realized
@@ -189,7 +185,7 @@ class TestStatsServicesConsumers(steps.BuildStepMixin, TestStatsServicesBase):
     """
 
     def setUp(self):
-        TestStatsServicesBase.setUp(self)
+        super().setUp()
         self.routingKey = (
             "builders", self.BUILDER_IDS[0], "builds", 1, "finished")
         self.master.mq.verifyMessages = False
@@ -218,7 +214,7 @@ class TestStatsServicesConsumers(steps.BuildStepMixin, TestStatsServicesBase):
             started_at=build['started_at'],
             complete=True,
             complete_at=build['complete_at'],
-            state_string=u'',
+            state_string='',
             results=0,
         )
 
@@ -391,8 +387,8 @@ class TestStatsServicesConsumers(steps.BuildStepMixin, TestStatsServicesBase):
             'duration', list(self.fake_storage_service.stored_data[0][0].keys())[0])
 
     def test_build_duration_report_in_error(self):
-        self.assertRaises(config.ConfigErrors,
-                          lambda: capture.CaptureBuildDuration('builder1', report_in='foobar'))
+        with self.assertRaises(config.ConfigErrors):
+            capture.CaptureBuildDuration('builder1', report_in='foobar')
 
     @defer.inlineCallbacks
     def test_build_duration_capturing_alt_callback(self):
