@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 from mock import Mock
 
 from twisted.internet import defer
@@ -39,7 +36,7 @@ from buildbot.test.util.interfaces import InterfaceTests
 
 
 @implementer(interfaces.ITriggerableScheduler)
-class FakeTriggerable(object):
+class FakeTriggerable:
 
     triggered_with = None
     result = SUCCESS
@@ -73,7 +70,7 @@ class TriggerableInterfaceTest(unittest.TestCase, InterfaceTests):
         self.assertInterfacesImplemented(FakeTriggerable)
 
 
-class FakeSourceStamp(object):
+class FakeSourceStamp:
 
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
@@ -82,7 +79,7 @@ class FakeSourceStamp(object):
         return self.__dict__.copy()
 
 
-class FakeSchedulerManager(object):
+class FakeSchedulerManager:
     pass
 
 
@@ -111,7 +108,7 @@ class TestTrigger(steps.BuildStepMixin, unittest.TestCase):
         sourcestamps = sourcestampsInBuild or []
         got_revisions = gotRevisionsInBuild or {}
 
-        steps.BuildStepMixin.setupStep(self, step, *args, **kwargs)
+        super().setupStep(step, *args, **kwargs)
 
         # This step reaches deeply into a number of parts of Buildbot.  That
         # should be fixed!
@@ -188,7 +185,7 @@ class TestTrigger(steps.BuildStepMixin, unittest.TestCase):
         if self.step.waitForFinish:
             for i in [11, 22, 33, 44]:
                 yield self.master.db.builds.finishBuild(BRID_TO_BID(i), results_dict.get(i, SUCCESS))
-        d = steps.BuildStepMixin.runStep(self)
+        d = super().runStep()
         # the build doesn't finish until after a callLater, so this has the
         # effect of checking whether the deferred has been fired already;
         if self.step.waitForFinish:
@@ -263,39 +260,38 @@ class TestTrigger(steps.BuildStepMixin, unittest.TestCase):
 
     # tests
     def test_no_schedulerNames(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger())
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger()
 
     def test_unimportantSchedulerNames_not_in_schedulerNames(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger(schedulerNames=['a'], unimportantsShedulerNames=['b']))
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger(schedulerNames=['a'],
+                            unimportantsShedulerNames=['b'])
 
     def test_sourceStamp_and_updateSourceStamp(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger(schedulerNames=['c'],
-                                          sourceStamp=dict(x=1), updateSourceStamp=True))
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger(schedulerNames=['c'], sourceStamp=dict(x=1),
+                            updateSourceStamp=True)
 
     def test_sourceStamps_and_updateSourceStamp(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger(schedulerNames=['c'],
-                                          sourceStamps=[dict(x=1), dict(x=2)],
-                                          updateSourceStamp=True))
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger(schedulerNames=['c'], sourceStamps=[dict(x=1),
+                            dict(x=2)], updateSourceStamp=True)
 
     def test_updateSourceStamp_and_alwaysUseLatest(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger(schedulerNames=['c'],
-                                          updateSourceStamp=True, alwaysUseLatest=True))
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger(schedulerNames=['c'], updateSourceStamp=True,
+                            alwaysUseLatest=True)
 
     def test_sourceStamp_and_alwaysUseLatest(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger(schedulerNames=['c'],
-                                          sourceStamp=dict(x=1), alwaysUseLatest=True))
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger(schedulerNames=['c'], sourceStamp=dict(x=1),
+                            alwaysUseLatest=True)
 
     def test_sourceStamps_and_alwaysUseLatest(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          trigger.Trigger(schedulerNames=['c'],
-                                          sourceStamps=[dict(x=1), dict(x=2)],
-                                          alwaysUseLatest=True))
+        with self.assertRaises(config.ConfigErrors):
+            trigger.Trigger(schedulerNames=['c'], sourceStamps=[dict(x=1),
+                            dict(x=2)], alwaysUseLatest=True)
 
     def test_simple(self):
         self.setupStep(trigger.Trigger(schedulerNames=['a'], sourceStamps={}))
