@@ -14,12 +14,7 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import PY3
-
 import hmac
-from calendar import timegm
 from copy import deepcopy
 from hashlib import sha1
 from io import BytesIO
@@ -100,7 +95,7 @@ gitJsonPayload = b"""
 }
 """
 
-gitJsonPayloadCiSkipTemplate = u"""
+gitJsonPayloadCiSkipTemplate = """
 {
   "before": "5aef35982fb2d34e9d9d4502f6ede1072793222d",
   "repository": {
@@ -524,10 +519,10 @@ _CT_ENCODED = b'application/x-www-form-urlencoded'
 _CT_JSON = b'application/json'
 
 
-def _prepare_github_change_hook(**params):
+def _prepare_github_change_hook(testcase, **params):
     return ChangeHookResource(dialects={
         'github': params
-    }, master=fakeMasterForHooks())
+    }, master=fakeMasterForHooks(testcase))
 
 
 def _prepare_request(event, payload, _secret=None, headers=None):
@@ -571,7 +566,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         self.changeHook = _prepare_github_change_hook(
-            strict=False, github_property_whitelist=["github.*"])
+            self, strict=False, github_property_whitelist=["github.*"])
         self.master = self.changeHook.master
         fake_headers = {'User-Agent': 'Buildbot'}
         self._http = yield fakehttpclientservice.HTTPClientService.getFakeService(
@@ -596,7 +591,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.request = _prepare_request(bad_event, gitJsonPayload)
         yield self.request.test_render(self.changeHook)
         expected = b'Unknown event: ' + bad_event
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     @defer.inlineCallbacks
@@ -607,14 +602,14 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         })
         yield self.request.test_render(self.changeHook)
         expected = b'Unknown content type: '
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertIn(expected, self.request.written)
 
     @defer.inlineCallbacks
     def _check_ping(self, payload):
         self.request = _prepare_request(b'ping', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
 
     def test_ping_encoded(self):
         self._check_ping([b'{}'])
@@ -627,8 +622,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.request = _prepare_request(b'push', gitJsonPayloadTag)
         yield self.request.test_render(self.changeHook)
 
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
         self.assertEqual(change["branch"], "v1.0.0")
@@ -639,8 +634,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.request = _prepare_request(b'push', gitJsonPayloadCreateTag)
         yield self.request.test_render(self.changeHook)
 
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change["author"],
                          "User <userid@example.com>")
         self.assertEqual(change["branch"], "v0.9.15.post1")
@@ -652,13 +647,13 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
     def _check_git_with_change(self, payload):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
+        change = self.changeHook.master.data.updates.changesAdded[0]
 
         self.assertEqual(change['files'], ['filepath.rb'])
         self.assertEqual(change["repository"],
                          "http://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1203116237)
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
@@ -671,11 +666,11 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
                          "http://github.com/defunkt/github/commit/"
                          "41a212ee83ca127e3c8cf465891ab7216a705f59")
 
-        change = self.changeHook.master.addedChanges[1]
+        change = self.changeHook.master.data.updates.changesAdded[1]
         self.assertEqual(change['files'], ['modfile', 'removedFile'])
         self.assertEqual(change["repository"],
                          "http://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1203114994)
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
@@ -711,13 +706,13 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
                                                                         b'"distinct": false,')])
 
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
 
-        change = self.changeHook.master.addedChanges[0]
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change['files'], ['filepath.rb'])
         self.assertEqual(change["repository"],
                          "http://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1203116237)
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
@@ -732,11 +727,11 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.assertEqual(change["properties"]["github_distinct"],
                          False)
 
-        change = self.changeHook.master.addedChanges[1]
+        change = self.changeHook.master.data.updates.changesAdded[1]
         self.assertEqual(change['files'], ['modfile', 'removedFile'])
         self.assertEqual(change["repository"],
                          "http://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1203114994)
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
@@ -754,11 +749,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.request = _prepare_request(b'push', b'')
 
         yield self.request.test_render(self.changeHook)
-        if PY3:
-            expected = b"Expecting value: line 1 column 1 (char 0)"
-        else:
-            expected = b"No JSON object could be decoded"
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        expected = b"Expecting value: line 1 column 1 (char 0)"
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
         self.request.setResponseCode.assert_called_with(400, expected)
 
@@ -767,7 +759,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
         expected = b"no change found"
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     def test_git_with_no_changes_encoded(self):
@@ -781,7 +773,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
         expected = b"no change found"
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     def test_git_with_non_branch_changes_encoded(self):
@@ -794,11 +786,11 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
     def _check_git_with_pull(self, payload):
         self.request = _prepare_request('pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change["repository"],
                          "https://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1412899790)
         self.assertEqual(change["author"],
                          "defunkt")
@@ -827,7 +819,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
     def _check_git_push_with_skip_message(self, payload):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
 
     def test_git_push_with_skip_message(self):
         gitJsonPayloadCiSkips = [
@@ -843,7 +835,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase):
     def _check_git_pull_request_with_skip_message(self, payload):
         self.request = _prepare_request(b'pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
 
     def test_git_pull_request_with_skip_message(self):
         api_endpoint = '/repos/defunkt/github/commits/05c588ba8cd510ecbe112d020f215facb17817a7'
@@ -865,7 +857,8 @@ class TestChangeHookConfiguredWithGitChangeCustomPullrequestRef(unittest.TestCas
     @defer.inlineCallbacks
     def setUp(self):
         self.changeHook = _prepare_github_change_hook(
-            strict=False, github_property_whitelist=["github.*"], pullrequest_ref="head")
+            self, strict=False, github_property_whitelist=["github.*"],
+            pullrequest_ref="head")
         self.master = self.changeHook.master
         fake_headers = {'User-Agent': 'Buildbot'}
         self._http = yield fakehttpclientservice.HTTPClientService.getFakeService(
@@ -884,8 +877,8 @@ class TestChangeHookConfiguredWithGitChangeCustomPullrequestRef(unittest.TestCas
         self._http.expect('get', api_endpoint, content_json=gitJsonPayloadCommit)
         self.request = _prepare_request('pull_request', commit)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change["branch"], "refs/pull/50/head")
 
 
@@ -894,7 +887,7 @@ class TestChangeHookConfiguredWithCustomSkips(unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         self.changeHook = _prepare_github_change_hook(
-            strict=False, skips=[r'\[ *bb *skip *\]'])
+            self, strict=False, skips=[r'\[ *bb *skip *\]'])
         self.master = self.changeHook.master
         fake_headers = {'User-Agent': 'Buildbot'}
         self._http = yield fakehttpclientservice.HTTPClientService.getFakeService(
@@ -910,7 +903,7 @@ class TestChangeHookConfiguredWithCustomSkips(unittest.TestCase):
     def _check_push_with_skip_message(self, payload):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
 
     def test_push_with_skip_message(self):
         gitJsonPayloadCiSkips = [
@@ -925,7 +918,7 @@ class TestChangeHookConfiguredWithCustomSkips(unittest.TestCase):
     def _check_push_no_ci_skip(self, payload):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
 
     def test_push_no_ci_skip(self):
         # user overrode the skip pattern already,
@@ -938,7 +931,7 @@ class TestChangeHookConfiguredWithCustomSkips(unittest.TestCase):
     def _check_pull_request_with_skip_message(self, payload):
         self.request = _prepare_request(b'pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
 
     def test_pull_request_with_skip_message(self):
         api_endpoint = '/repos/defunkt/github/commits/05c588ba8cd510ecbe112d020f215facb17817a7'
@@ -957,7 +950,7 @@ class TestChangeHookConfiguredWithCustomSkips(unittest.TestCase):
     def _check_pull_request_no_skip(self, payload):
         self.request = _prepare_request(b'pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
 
     def test_pull_request_no_skip(self):
         api_endpoint = '/repos/defunkt/github/commits/05c588ba8cd510ecbe112d020f215facb17817a7'
@@ -974,7 +967,7 @@ class TestChangeHookConfiguredWithAuth(unittest.TestCase):
     def setUp(self):
         _token = '7e076f41-b73a-4045-a817'
         self.changeHook = _prepare_github_change_hook(
-            strict=False, token=_token)
+            self, strict=False, token=_token)
         self.master = self.changeHook.master
         fake_headers = {'User-Agent': 'Buildbot',
                 'Authorization': 'token ' + _token}
@@ -991,7 +984,7 @@ class TestChangeHookConfiguredWithAuth(unittest.TestCase):
     def _check_pull_request(self, payload):
         self.request = _prepare_request(b'pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
 
     def test_pull_request(self):
         api_endpoint = '/repos/defunkt/github/commits/05c588ba8cd510ecbe112d020f215facb17817a7'
@@ -1005,7 +998,7 @@ class TestChangeHookConfiguredWithCustomApiRoot(unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         self.changeHook = _prepare_github_change_hook(
-            strict=False, github_api_endpoint='https://black.magic.io')
+            self, strict=False, github_api_endpoint='https://black.magic.io')
         self.master = self.changeHook.master
         fake_headers = {'User-Agent': 'Buildbot'}
         self._http = yield fakehttpclientservice.HTTPClientService.getFakeService(
@@ -1021,7 +1014,7 @@ class TestChangeHookConfiguredWithCustomApiRoot(unittest.TestCase):
     def _check_pull_request(self, payload):
         self.request = _prepare_request(b'pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
 
     def test_pull_request(self):
         api_endpoint = '/repos/defunkt/github/commits/05c588ba8cd510ecbe112d020f215facb17817a7'
@@ -1036,7 +1029,7 @@ class TestChangeHookConfiguredWithCustomApiRootWithAuth(unittest.TestCase):
     def setUp(self):
         _token = '7e076f41-b73a-4045-a817'
         self.changeHook = _prepare_github_change_hook(
-            strict=False, github_api_endpoint='https://black.magic.io',
+            self, strict=False, github_api_endpoint='https://black.magic.io',
             token=_token)
         self.master = self.changeHook.master
         fake_headers = {'User-Agent': 'Buildbot',
@@ -1054,7 +1047,7 @@ class TestChangeHookConfiguredWithCustomApiRootWithAuth(unittest.TestCase):
     def _check_pull_request(self, payload):
         self.request = _prepare_request(b'pull_request', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 1)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 1)
 
     def test_pull_request(self):
         api_endpoint = '/repos/defunkt/github/commits/05c588ba8cd510ecbe112d020f215facb17817a7'
@@ -1068,7 +1061,7 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
     _SECRET = 'somethingreallysecret'
 
     def setUp(self):
-        self.changeHook = _prepare_github_change_hook(strict=True,
+        self.changeHook = _prepare_github_change_hook(self, strict=True,
                                                       secret=self._SECRET)
 
     @defer.inlineCallbacks
@@ -1077,13 +1070,13 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
                                         _secret=self._SECRET)
         yield self.request.test_render(self.changeHook)
         # Can it somehow be merged w/ the same code above in a different class?
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
+        change = self.changeHook.master.data.updates.changesAdded[0]
 
         self.assertEqual(change['files'], ['filepath.rb'])
         self.assertEqual(change["repository"],
                          "http://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1203116237)
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
@@ -1096,11 +1089,11 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
                          "http://github.com/defunkt/github/commit/"
                          "41a212ee83ca127e3c8cf465891ab7216a705f59")
 
-        change = self.changeHook.master.addedChanges[1]
+        change = self.changeHook.master.data.updates.changesAdded[1]
         self.assertEqual(change['files'], ['modfile', 'removedFile'])
         self.assertEqual(change["repository"],
                          "http://github.com/defunkt/github")
-        self.assertEqual(timegm(change["when_timestamp"].utctimetuple()),
+        self.assertEqual(change["when_timestamp"],
                          1203114994)
         self.assertEqual(change["author"],
                          "Fred Flinstone <fred@flinstone.org>")
@@ -1121,7 +1114,7 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
         })
         yield self.request.test_render(self.changeHook)
         expected = b'Unknown hash type: ' + bad_hash_type
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     @defer.inlineCallbacks
@@ -1132,17 +1125,17 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
         })
         yield self.request.test_render(self.changeHook)
         expected = b'Hash mismatch'
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     @defer.inlineCallbacks
     def test_missing_secret(self):
         # override the value assigned in setUp
-        self.changeHook = _prepare_github_change_hook(strict=True)
+        self.changeHook = _prepare_github_change_hook(self, strict=True)
         self.request = _prepare_request(b'push', gitJsonPayload)
         yield self.request.test_render(self.changeHook)
         expected = b'Strict mode is requested while no secret is provided'
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     @defer.inlineCallbacks
@@ -1153,7 +1146,7 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
         })
         yield self.request.test_render(self.changeHook)
         expected = b'Wrong signature format: ' + bad_signature
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
     @defer.inlineCallbacks
@@ -1161,21 +1154,21 @@ class TestChangeHookConfiguredWithStrict(unittest.TestCase):
         self.request = _prepare_request(b'push', gitJsonPayload)
         yield self.request.test_render(self.changeHook)
         expected = b'Request has no required signature'
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertEqual(self.request.written, expected)
 
 
 class TestChangeHookConfiguredWithCodebaseValue(unittest.TestCase):
 
     def setUp(self):
-        self.changeHook = _prepare_github_change_hook(codebase='foobar')
+        self.changeHook = _prepare_github_change_hook(self, codebase='foobar')
 
     @defer.inlineCallbacks
     def _check_git_with_change(self, payload):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change['codebase'], 'foobar')
 
     def test_git_with_change_encoded(self):
@@ -1193,14 +1186,14 @@ class TestChangeHookConfiguredWithCodebaseFunction(unittest.TestCase):
 
     def setUp(self):
         self.changeHook = _prepare_github_change_hook(
-            codebase=_codebase_function)
+            self, codebase=_codebase_function)
 
     @defer.inlineCallbacks
     def _check_git_with_change(self, payload):
         self.request = _prepare_request(b'push', payload)
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 2)
-        change = self.changeHook.master.addedChanges[0]
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
+        change = self.changeHook.master.data.updates.changesAdded[0]
         self.assertEqual(change['codebase'], 'foobar-github')
 
     def test_git_with_change_encoded(self):
@@ -1219,11 +1212,11 @@ class TestChangeHookConfiguredWithCustomEventHandler(unittest.TestCase):
                 return [], None
 
         self.changeHook = _prepare_github_change_hook(
-            **{'class': CustomGitHubEventHandler})
+            self, **{'class': CustomGitHubEventHandler})
 
     @defer.inlineCallbacks
     def test_ping(self):
         self.request = _prepare_request(b'ping', b'{}')
         yield self.request.test_render(self.changeHook)
-        self.assertEqual(len(self.changeHook.master.addedChanges), 0)
+        self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 0)
         self.assertTrue(self.changeHook.master.hook_called)
