@@ -13,19 +13,24 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 from future.utils import text_type
 
 import os
 import sys
 
+from twisted.python import log
+from twisted.python import threadpool
 from twisted.python.compat import NativeStringIO
+from twisted.trial.unittest import TestCase
 
 import buildbot
+from buildbot.process.buildstep import BuildStep
+from buildbot.test.fake.reactor import NonThreadPool
+from buildbot.test.fake.reactor import TestReactor
+from buildbot.util.eventual import _setReactor
 
 
-class PatcherMixin(object):
+class PatcherMixin:
 
     """
     Mix this in to get a few special-cased patching methods
@@ -43,7 +48,7 @@ class PatcherMixin(object):
             os.uname = replacement
 
 
-class StdoutAssertionsMixin(object):
+class StdoutAssertionsMixin:
 
     """
     Mix this in to be able to assert on stdout during the test
@@ -63,6 +68,42 @@ class StdoutAssertionsMixin(object):
         return self.stdout.getvalue().strip()
 
 
+class TestReactorMixin:
+
+    """
+    Mix this in to get TestReactor as self.reactor which is correctly cleaned up
+    at the end
+    """
+    def setUpTestReactor(self):
+        self.patch(threadpool, 'ThreadPool', NonThreadPool)
+        self.reactor = TestReactor()
+        _setReactor(self.reactor)
+        # During shutdown sequence we must first stop the reactor and only then
+        # set unset the reactor used for eventually() because any callbacks
+        # that are run during reactor.stop() may use eventually() themselves.
+        self.addCleanup(_setReactor, None)
+        self.addCleanup(self.reactor.stop)
+
+
+class TimeoutableTestCase(TestCase):
+    # The addCleanup in current Twisted does not time out any functions
+    # registered via addCleanups. Until we can depend on fixed Twisted, use
+    # TimeoutableTestCase whenever test failure may cause it to block and not
+    # report anything.
+
+    def deferRunCleanups(self, ignored, result):
+        self._deferRunCleanupResult = result
+        d = self._run('deferRunCleanupsTimeoutable', result)
+        d.addErrback(self._ebGotMaybeTimeout, result)
+        return d
+
+    def _ebGotMaybeTimeout(self, failure, result):
+        result.addError(self, failure)
+
+    def deferRunCleanupsTimeoutable(self):
+        return super().deferRunCleanups(None, self._deferRunCleanupResult)
+
+
 def encodeExecutableAndArgs(executable, args, encoding="utf-8"):
     """
     Encode executable and arguments from unicode to bytes.
@@ -84,8 +125,10 @@ def enable_trace(case, trace_exclusions=None, f=sys.stdout):
     """This function can be called to enable tracing of the execution
     """
     if trace_exclusions is None:
-        trace_exclusions = ["twisted", "worker_transition.py", "util/tu",
-                            "log.py", "/mq/", "/db/", "buildbot/data/", "fake/reactor.py"]
+        trace_exclusions = [
+            "twisted", "worker_transition.py", "util/tu", "util/path",
+            "log.py", "/mq/", "/db/", "buildbot/data/", "fake/reactor.py"
+        ]
 
     bbbase = os.path.dirname(buildbot.__file__)
     state = {'indent': 0}
@@ -103,3 +146,19 @@ def enable_trace(case, trace_exclusions=None, f=sys.stdout):
 
     sys.settrace(tracefunc)
     case.addCleanup(sys.settrace, lambda _a, _b, _c: None)
+
+
+class DebugIntegrationLogsMixin:
+
+    def setupDebugIntegrationLogs(self):
+        # to ease debugging we display the error logs in the test log
+        origAddCompleteLog = BuildStep.addCompleteLog
+
+        def addCompleteLog(self, name, _log):
+            if name.endswith("err.text"):
+                log.msg("got error log!", name, _log)
+            return origAddCompleteLog(self, name, _log)
+        self.patch(BuildStep, "addCompleteLog", addCompleteLog)
+
+        if 'BBTRACE' in os.environ:
+            enable_trace(self)
